/***************************************************************************
 *   Copyright (C) 2009 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef MAGNETTEST_H
#define MAGNETTEST_H

#include <QObject>

#include <magnet/magnetlink.h>
#include <magnet/magnetdownloader.h>

namespace bt
{
    class UPnPRouter;
    class UPnPMCastSocket;
}


class MagnetTest : public QObject
{
public:
    MagnetTest(const bt::MagnetLink& mlink, QObject* parent = 0);
    ~MagnetTest();

    void routerDiscovered(bt::UPnPRouter* router);
    void start();
    void update();
    void foundMetaData(bt::MagnetDownloader* md, const QByteArray& data);

private:
    bt::MagnetLink mlink;
    bt::UPnPMCastSocket* upnp;
    bt::MagnetDownloader* mdownloader;
    QTimer timer;
};

#endif // MAGNETTEST_H
